//---------------------------------------------------------------------------
// Copyright (C) 1999 Dallas Semiconductor Corporation, All Rights Reserved.
// 
// Permission is hereby granted, free of charge, to any person obtaining a 
// copy of this software and associated documentation files (the "Software"), 
// to deal in the Software without restriction, including without limitation 
// the rights to use, copy, modify, merge, publish, distribute, sublicense, 
// and/or sell copies of the Software, and to permit persons to whom the 
// Software is furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included 
// in all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS 
// OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF 
// MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. 
// IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES 
// OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, 
// ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR 
// OTHER DEALINGS IN THE SOFTWARE.
// 
// Except as contained in this notice, the name of Dallas Semiconductor 
// shall not be used except as stated in the Dallas Semiconductor 
// Branding Policy. 
//---------------------------------------------------------------------------
//
//  owatod.h - Include file for 1-Wire A to D example.
//
//  Version: 1.00
//

// defines
#define ATOD_FAM           0x20
// setup 
#define NO_OUTPUT          0x00
#define OUTPUT_ON          0x80
#define OUTPUT_OFF         0xC0
#define RANGE_512          0x01
#define RANGE_256          0x00
#define ALARM_HIGH_ENABLE  0x08
#define ALARM_LOW_ENABLE   0x04
#define ALARM_HIGH_DISABLE 0x00
#define ALARM_LOW_DISABLE  0x00
#define BITS_16            0x00
#define BITS_8             0x08
// output level contants
#define LV_ALWAYS                   2
#define LV_OPTIONAL                 1
#define LV_VERBOSE                  0

// basic types
typedef unsigned char  uchar;
typedef unsigned short ushort;
typedef unsigned long  ulong;

// structure to hold each state in the StateMachine
typedef struct
{
   int  Step;
   char StepDescription[50];
} Script;


// step constants
enum { ST_SETUP=0, ST_FIND_ATOD, ST_WRITE_SETUP, ST_GET_SESSION, 
       ST_REL_SESSION, ST_READ_RSLTS, ST_GET_SETUP, 
       ST_DO_CONV, ST_FINISH };

// status contants
enum { STATUS_STEP_COMPLETE, STATUS_COMPLETE, STATUS_INPROGRESS,
       STATUS_ERROR_HALT, STATUS_ERROR_TRANSIENT };

#ifdef TMEXUTIL

// setup steps
Script SetupAtoD[] = 
    {{ ST_GET_SESSION,  "Aquire a session" }, 
     { ST_SETUP,        "Verify 1-Wire"},
     { ST_FIND_ATOD,    "Search for A to D"},
     { ST_GET_SETUP,    "Get A to D setup"},
     { ST_WRITE_SETUP,  "Write A to D setup"},
     { ST_REL_SESSION,  "Release the session" },
     { ST_FINISH,       "Finished"}}; 

// read A to D
Script ReadAtoD[] = 
    {{ ST_DO_CONV,      "Perform the A to D conversion"},
     { ST_READ_RSLTS,   "Read A to D results"},
     { ST_FINISH,       "Finished"}}; 

// open the sessions
Script OpenSession[] = 
    {{ ST_GET_SESSION,    "Aquire a session" }, 
     { ST_FINISH,         "Finished"}}; 

// open the sessions
Script CloseSession[] = 
    {{ ST_REL_SESSION,    "Release the session" },
     { ST_FINISH,         "Finished"}}; 

#else

extern Script SetupAtoD[];
extern Script ReadAtoD[];
extern Script OpenSession[];
extern Script CloseSession[];

#endif